# > ℹ️ **Note:** Alert do not use yet.

**The Form Service Dynamic Library: Under Development and Awaiting Maturation**

In today's rapidly evolving technological landscape, the quest for efficient and dynamic solutions is ceaseless. One area that is constantly evolving is the development of libraries and frameworks that facilitate the creation of robust and functional applications. In this context, the Form Service Dynamic library has garnered interest and curiosity. However, it is essential to address the question of its readiness for use in production environments.

The Form Service Dynamic library aims to offer an innovative approach to creating dynamic forms, with the goal of making the development process more agile and effective. It seeks to provide a range of features that enable the creation of interactive and adaptable forms, spanning from data validation to the generation of dynamic interfaces. The concept behind this library is undoubtedly promising and could provide significant advantages for various projects.

However, it is important to emphasize that the Form Service Dynamic library is still in active development. This means that the library is subject to frequent changes in its structure, functionalities, and API. While the library's proposition is promising, it is crucial to understand that using a library in active development may pose substantial challenges.

Some of the potential obstacles associated with using Form Service Dynamic while it is in development include:

1. **Instability**: Libraries in development may exhibit instability, bugs, and unpredictable behavior, making it difficult to build reliable and consistent applications.

2. **Lack of Comprehensive Documentation**: Inadequate or constantly changing documentation can make it challenging to understand and implement the library's features.

3. **Deprecation of Features**: Resources and functionalities you use today might be modified or removed in upcoming versions, potentially leading to significant rework.

4. **Limited Support**: During the development phase, technical support might be limited or unavailable, making it more challenging to resolve issues or questions.

5. **Future Compatibility**: The library may evolve in a way that makes previous versions incompatible, which can pose difficulties in updating and maintaining projects.

Therefore, while the Form Service Dynamic Library presents significant potential for simplifying the creation of dynamic forms, it is advisable to exercise caution when considering its adoption in production projects. Before integrating it into your workflow, it is recommended to wait until it reaches a more mature level of development, with solid documentation, stability, and adequate support.

By monitoring the progress and maturation of the Form Service Dynamic Library, you will be better equipped to make the most of its benefits while minimizing the inherent risks and challenges of using a library in active development.


# FormServiceDynamic

[![GitHub top language](https://img.shields.io/github/languages/top/JeanPaulll/lib-form-service#readme.svg)]()
[![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/JeanPaulll/lib-form-service.svg)]()
[![GitHub issues](https://img.shields.io/github/issues/JeanPaulll/lib-form-service.svg)]()
[![GitHub closed issues](https://img.shields.io/github/issues-closed/JeanPaulll/lib-form-service.svg)]()
[![GitHub contributors](https://img.shields.io/github/contributors/JeanPaulll/lib-form-service.svg)]()
[![GitHub](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/JeanPaulll/lib-form-service)
[![npm](https://img.shields.io/npm/v/handle-json-payload.svg)]()
[![Website](https://img.shields.io/website-up-down-green-red/http/shields.io.svg?label=agenciacriamais)](http://www.agenciacriamais.com.br)

The `FormServiceDynamic` is a utility library for creating Angular forms with ease. It provides a simple way to generate
reactive forms and apply validations to form controls.

## Installation

You can install the FormServiceDynamic package using npm:

```bash
npm install form-service-dynamic --save
```

## Use in your component

```typescript
import {Component, OnInit} from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import {FormServiceDynamic, FieldConfig} from 'form-service-dynamic'; // Make sure to adjust the import path based on your project structure

interface Person {
    name: string;
    age: number;
    phones: Phone[];
}

interface Phone {
    number: string | null;
    description: string | null;
    types: string[];
}

@Component({
    selector: 'app-your-component',
    templateUrl: './your-component.component.html',
    styleUrls: ['./your-component.component.css']
})
export class YourComponent implements OnInit {
    personForm!: FormGroup;

    constructor(private formService: FormServiceDynamic) {
    }

    ngOnInit(): void {
        this.createForm();
    }

    private createForm(): void {
        const person: Person = {
            name: '',
            age: null,
            phones: []
        };
        this.personForm = this.formService.createForm(person);
    }
}
```

## Usage in Service

1. Import the necessary classes and interfaces from the `@angular/forms` module and the `form-service` package:

```typescript
import {
    FormBuilder,
    FormGroup,
    FormControl,
    Validators,
    ValidatorFn,
    AsyncValidatorFn,
    AbstractControl
} from '@angular/forms';
import {FormServiceDynamic, FieldConfig} from 'form-service-dynamic';
```

2. Create an instance of `FormServiceDynamic` by injecting `FormBuilder`:

```typescript
@Injectable({
    providedIn: 'root'
})
export class YourFormService extends FormServiceDynamic {
    constructor(private formBuilder: FormBuilder) {
        super(formBuilder);
    }

    // Your custom form creation methods can go here
}
```

3. Define your form configuration using the `CampoConfig` interface:

```typescript
interface Phone {
    number: string | null;
    description: string | null;
    types: string[];
}

interface Person {
    name: string | null;
    age: number | null;
    phones: Phone[];
}

const phone: Phone = {
    number: '',
    description: '',
    types: []
};

const person: Person = {
    name: '',
    age: null,
    phones: [phone]
};
```

4. Use the `createForm` method from `FormServiceDynamic` to generate the form:

```typescript
const options: { [field: string]: CampoConfig } = {
    name: {value: '', validations: {required: true}},
    age: {value: null, validations: {required: true, min: 18}},
    phones: {value: [], validations: {required: true}}
};

const personForm: FormGroup = this.createForm(person, options);
```

5. Use the generated form in your component template:

```html

<form [formGroup]="personForm">
    <label for="name">Name:</label>
    <input type="text" id="name" formControlName="name">
    <!-- More form controls for other fields... -->
</form>
```

6. Custom Validators

```typescript
const options: { [field: string]: CampoConfig } = {
    name: {
        value: '',
        customValidation: (control: AbstractControl) => {
            if (control.value && control.value.toLowerCase() === 'admin') {
                return {forbiddenName: true};
            }
            return null;
        }
    },
// Other fields...
};
```

## Help improve

Found a bug or a problem? [Open a new issue](https://github.com/JeanPaulll/lib-form-service/issues)  GitHub.

## Contributing to this project

[GitHub](https://github.com/JeanPaulll/lib-form-service)

## Author

[@JeanPaul](https://twitter.com/jeanpaullx) – jeanpaulwebb@gmail.com

[![GitHub contributors](https://img.shields.io/github/contributors/JeanPaulll/lib-form-service.svg)]()

License
This project is licensed under the MIT License - see the LICENSE file for details.




